@@ -46,7 +46,7 @@ var NAVTREE =
         [ "Typedefs", "functions_type.html", null ],
         [ "Enumerations", "functions_enum.html", null ],
         [ "Enumerator", "functions_eval.html", null ],
-        [ "Related Functions", "functions_rela.html", null ]
+        [ "Related Symbols", "functions_rela.html", null ]
       ] ]
     ] ],
     [ "Files", "files.html", [
@@ -58,18 +58,18 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "a00674.html",
-"a00912.html#a3028c0c590987aeff1b0ba195abff446",
-"a00957.html#aa7e32ce7ba896c5ddfe6521ad0022ce2",
-"a00993.html#a1d27edb01bfb68ba50776b25aa437783",
-"a01017.html#a19202138f911782b5652536867d24565",
-"a01069.html#aa71d36872f416feaa853788a7a7a7ef8",
-"a01113.html#ac5eadebfdd9b11ac383653e5a2383231",
-"a01161.html#a6a642b61f5cf7ced73523798467735a5",
-"a01205.html#ad9941ba7019b0fd8aad6e9321d91c26a",
-"a01261.html#a15628b18e19d90e91fdbd659925ae5c0",
-"a01301.html#a77cee40767fd4936f20a8f9d9d9ea625",
-"a01333.html#ab38c56ce6121aed94f2796bf5df894be"
+"a00921.html#a43caa8212032f3649809914cc0f57653",
+"a00961.html#a7a3e89992f3cc492804ec9bc184a1674",
+"a00993.html#a5b32465be706d80f4fac5ea05e3e0ded",
+"a01041.html",
+"a01089.html#ab7c383a49298cf060574242fe679378f",
+"a01129.html#a5561c34bac948dc836506e8e8d3ee134",
+"a01173.html#a89d1a006bc57adefbd8cc2b3221507d8",
+"a01221.html#a2c24b70c9312d8dff3fecb9ddea52c44",
+"a01277.html#a1b564bc13c46807d779bd7e9a74a6e73",
+"a01325.html#a765b0b2b5c9deb2c5fb50fa0ae6d6b0a",
+"a01345.html#a3519e5e05631026fad94c7616f5e0e67"
 ];
 
-var SYNCONMSG = 'click to disable panel synchronisation';
-var SYNCOFFMSG = 'click to enable panel synchronisation';
\ No newline at end of file
+var SYNCONMSG = 'click to disable panel synchronization';
+var SYNCOFFMSG = 'click to enable panel synchronization';
\ No newline at end of file
